@@ -575,24 +575,15 @@ on_button_release(GtkWidget* widget, GdkEventButton *button_event, gpointer data
     self->rec_button_down = FALSE;
     self->stop_button_down = FALSE;
 
-    if (button_event->x >= self->button_rec->allocation.x &&
-        button_event->y >= self->button_rec->allocation.y &&
-        button_event->x <= self->button_rec->allocation.x +
-                       self->button_rec->allocation.width &&
-        button_event->y <= self->button_rec->allocation.y +
-                       self->button_rec->allocation.height &&
-        self->rec_button_enabled) {
-            handle_button_press(self->button_rec, self);
-    } else if (button_event->x >= self->button_stop->allocation.x &&
-        button_event->y >= self->button_stop->allocation.y &&
-        button_event->x <= self->button_stop->allocation.x +
-                       self->button_stop->allocation.width &&
-        button_event->y <= self->button_stop->allocation.y +
-                       self->button_stop->allocation.height &&
-        self->stop_button_enabled) {
-            handle_button_press(self->button_stop, self);
-    }	
-    
+    if ((widget == GTK_WIDGET(self->button_rec)) && self->rec_button_enabled)
+        {
+	handle_button_press(self->button_rec, self);
+	}
+    else if ((widget == GTK_WIDGET(self->button_stop)) && self->stop_button_enabled)
+        {
+        handle_button_press(self->button_stop, self);
+	}
+
     return FALSE;
 }
 
@@ -601,22 +592,13 @@ on_button_press(GtkWidget* widget, GdkEventButton *button_event, gpointer data)
 {
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (data);
 
-    if (button_event->x >= self->button_rec->allocation.x &&
-        button_event->y >= self->button_rec->allocation.y &&
-        button_event->x <= self->button_rec->allocation.x +
-                       self->button_rec->allocation.width &&
-        button_event->y <= self->button_rec->allocation.y +
-                       self->button_rec->allocation.height &&
+    if ((widget == GTK_WIDGET(self->button_rec)) &&
         self->rec_button_enabled)
     {
         self->rec_button_down = TRUE;
         gtk_widget_queue_draw(widget);
-    } else if (button_event->x >= self->button_stop->allocation.x &&
-        button_event->y >= self->button_stop->allocation.y &&
-        button_event->x <= self->button_stop->allocation.x +
-                       self->button_stop->allocation.width &&
-        button_event->y <= self->button_stop->allocation.y +
-                       self->button_stop->allocation.height &&
+    }
+    else if ((widget == GTK_WIDGET(self->button_stop)) &&
         self->stop_button_enabled)
     {
         self->stop_button_down = TRUE;
@@ -1047,10 +1029,13 @@ gps_data_logger_widget_init (GpsDataLoggerWidget * self)
 		    self);
 
     /* button signals */
-
-    g_signal_connect(G_OBJECT(self->background), "button-release-event",
+    g_signal_connect(G_OBJECT(self->button_rec), "button-release-event",
                     G_CALLBACK(on_button_release), self);
-    g_signal_connect(G_OBJECT(self->background), "button-press-event",
+    g_signal_connect(G_OBJECT(self->button_rec), "button-press-event",
+                    G_CALLBACK(on_button_press), self);
+    g_signal_connect(G_OBJECT(self->button_stop), "button-release-event",
+                    G_CALLBACK(on_button_release), self);
+    g_signal_connect(G_OBJECT(self->button_stop), "button-press-event",
                     G_CALLBACK(on_button_press), self);
     g_signal_connect(G_OBJECT(self->background), "leave-notify-event",
                     G_CALLBACK(on_widget_leave), self);
@@ -1072,6 +1057,8 @@ static void
 gps_data_logger_widget_finalize (GObject *object)
 {
     GpsDataLoggerWidget *self = GPS_DATA_LOGGER_WIDGET (object);
+    /* Close the logfile if it is open */
+    logfile_close(self);
     g_object_unref(self->device);
     g_object_unref(self->control);
     if (self->settings_dialog) {
